@@ -100,7 +100,7 @@ def Package(File, Ofter="-w", StartMenu: bool = True):
         from shutil import move
         Shell = Dispatch("WScript.Shell")
         ShortCut = Shell.CreateShortCut(name+".lnk")
-        ShortCut.TargetPath = os.getcwd()+path
+        ShortCut.TargetPath = os.getcwd()+"\\"+path
         ShortCut.save()
         move(name+".lnk", f"C:\\Users\\{getuser()}\\AppData\\Roaming\\Microsoft\\Windows\\Start Menu\\Programs")
 
